#!/usr/bin/env python3
# -*- coding=utf-8 -*-

import sys
import asyncio
import subprocess

from time import sleep
from bleak import BleakScanner, exc
from loguru import logger

if len(sys.argv) != 2:
    raise SystemExit("Usage: %s mac_addr" % sys.argv[0])

mac_addr = sys.argv[1].upper()

def is_locked():
    out = subprocess.run(['loginctl', 'list-sessions', '--no-legend'], capture_output=True)
    sess_num = out.stdout.split()[0]
    out = subprocess.run(['loginctl', 'show-session', sess_num, '-p', 'LockedHint', '--value'], capture_output=True)
    return b'yes' in out.stdout

def is_fullscreen():
    out = subprocess.run(['check-fullscreen'], capture_output=True)
    return b'fullscreen' in out.stdout

async def find_device(mac_addr):
    try:
        devices = [x.address for x in await BleakScanner.discover()]
    except exc.BleakError as err:
        return err

    return mac_addr in devices

async def main():
    while True:
        device_found = await find_device(mac_addr)

        match device_found:
            case exc.BleakError() as err:
                logger.error(f"ERROR: {err}")
                break
            case True if is_locked():
                logger.info('device present: unlocking')
                subprocess.run(['loginctl', 'unlock-session'])
            case _ if not is_locked() and not is_fullscreen():
                sleep(60)
                device_found = await find_device(mac_addr)

                if device_found is False:
                    logger.info('device not present: locking')
                    subprocess.run(['loginctl', 'lock-session'])

        await asyncio.sleep(300)

asyncio.run(main())
